pub struct DotFormatter<'g, G: LinkView> { /* private fields */ }Expand description
Configurable mermaid formatter for a PortGraph.
Implementations
Sourceimpl<'g, G> DotFormatter<'g, G>where
G: LinkView,
impl<'g, G> DotFormatter<'g, G>where
G: LinkView,
Sourcepub fn with_hierarchy(self, forest: &'g Hierarchy<G::NodeIndexBase>) -> Self
pub fn with_hierarchy(self, forest: &'g Hierarchy<G::NodeIndexBase>) -> Self
Set the Hierarchy to use for the graph.
Sourcepub fn with_node_style(
self,
node_style: impl FnMut(NodeIndex<G::NodeIndexBase>) -> NodeStyle + 'g,
) -> Self
pub fn with_node_style( self, node_style: impl FnMut(NodeIndex<G::NodeIndexBase>) -> NodeStyle + 'g, ) -> Self
Set the function to use to get the style of a node.
Sourcepub fn with_port_style(
self,
port_style: impl FnMut(PortIndex<G::PortIndexBase>) -> PortStyle + 'g,
) -> Self
pub fn with_port_style( self, port_style: impl FnMut(PortIndex<G::PortIndexBase>) -> PortStyle + 'g, ) -> Self
Set the function to use to get the style of a port.
Sourcepub fn with_edge_style(
self,
edge_style: impl FnMut(G::LinkEndpoint, G::LinkEndpoint) -> EdgeStyle + 'g,
) -> Self
pub fn with_edge_style( self, edge_style: impl FnMut(G::LinkEndpoint, G::LinkEndpoint) -> EdgeStyle + 'g, ) -> Self
Set the function to use to get the style of an edge.
Sourcepub fn with_weights<'w, N, P>(
self,
weights: &'w Weights<N, P, G::NodeIndexBase, G::PortIndexBase>,
) -> Self
pub fn with_weights<'w, N, P>( self, weights: &'w Weights<N, P, G::NodeIndexBase, G::PortIndexBase>, ) -> Self
Encode some Weights in the dot format.
This is a convenience method to set the node and port styles based on the weight values. It overrides any previous node or port style set.