pub struct PortGraph<N: IndexBase = u32, P: IndexBase = u32, PO: IndexBase = u16> { /* private fields */ }Expand description
An unlabelled port graph.
A port graph consists of a collection of nodes identified by a NodeIndex.
Each node has an ordered sequence of input and output ports, identified by a PortIndex that is unique within the graph.
To optimize for the most common use case, the number of input and output ports of a node must be specified when the node is created.
When a node and its associated ports are removed their indices will be reused on a best effort basis
when a new node is added.
The indices of unaffected nodes and ports remain stable.
PortGraph::compact_nodes and PortGraph::compact_ports to eliminate fragmentation in the index space.
Generic parameters
N: The unsigned integer type used for node indices.P: The unsigned integer type used for port indices.PO: The unsigned integer type used for port offsets.
Implementations